@@ -493,7 +493,9 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
     if (fr_data.no_invalid_replacements) {
         g_autofree gchar *replacements_done_label_txt;
-        const gchar *small_numbers_spelled_out[] = { N_("once"), N_("twice"), N_("three times"), N_("four times"), N_("five times"), 
+        const gchar *small_numbers_spelled_out[] = { // Translation note: "once" in the sense of "one time".
+                                                     N_("once"), 
+                                                     N_("twice"), N_("three times"), N_("four times"), N_("five times"), 
                                                      N_("six times"), N_("seven times"), N_("eight times"), N_("nine times") };
 
         fr_data.replacements_done_cnt = 0; // Default
